*----------------------------------------------------------------------------*
*  reading and evaluation of the top-quark anomalous couplings               *
*----------------------------------------------------------------------------*
      subroutine FCNC_READ
*     -------------------                                                    *
* anomalous couplings are from "Top quark physics", hep-ph/0003033, M.Beneke *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision mq,       mq2
      common  /massql/ mq(0:20), mq2(0:20)
      integer I 
* parameterization is : (par_L P_L + par_R P_R)                              *
* definition of other terms is determined by interaction                     *
*----------------------------                                                *
* input:                                                                     *
* ------                                                                     *
* three types of parameterizations (determined by IRtyp                      *
*  Irtyp(int) = 1 : ReA and ImA                                              *
*  Irtyp(int) = 2 : !A! and phase in radian, i.e. cos(phase)                 *
*  Irtyp(int) = 3 : |A| and phase in PI,     i.e. cos(PI*phase)              *
*  Irtyp(int) = 4 : |A| and phase , Rui&Pedro parameterization               *
*  Irtyp(int) = -1 : supress completely interaction                          *
*  Irtyp(int) = 10 + 1 (2, 3, 4) are the same as 1,2,3,4 but for f + h gamma5*
*   i.e. A_L = f - h,  A_R = f + h
* cH(i)  are divided by Rpar(50) (Lambda New Physics)                        *
* CX and CY are divided by Rpar(50)**2 (Lambda New Physics)                  *
* . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .*
      double precision x0, CX_MD, A 
      integer Irtyp, JK 
      double precision an_FL,an_FR,an_HL,an_HR,an_XL,an_XR,an_YL,an_YR
      common /CTOPINI/Irtyp(20), an_FL(2,20), an_FR(2,20),
     &   an_HL(2,20), an_HR(2,20), an_XL(2,20), an_XR(2,20), 
     &   an_YL(2,20), an_YR(2,20) 
      double complex   CR,  CL
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 

      character *9 nam(20)
      data nam
     &/'d W+- t  ','s W+- t  ','b W+- t  ','not used ',
     & 'b H+- t  ','b H+- T* ','not used ','not used ',
     & 'not used ','not used ','U gluon T','C gluon T',
     & 'U gamma T','C gamma T','U Z T    ','C Z T    ',
     & 'not used ','not used ','not used ','not used '/
***
      data Irtyp/20*1/
      data an_FL/
*      Re_FL  Im_FL         MID channel
     & 1.d0,  0.0d0,     ! 1   d W t SM 
     & 1.d0,  0.0d0,     ! 2   s W t SM 
     & 1.d0,  0.0d0,     ! 3   b W t SM 
     & 2*0.d0,           ! not used
     & 2*0.d0,           ! 5   b H+- 
     & 2*0.d0,           ! 6   b H+- T* 
     & 8*0.d0,           ! 7:10   not used
     & 0.d0,  0.d0,      ! 11 U_Gluon_T  
     & 0.d0,  1.d0,      ! 12 C_Gluon_T  
     & 0.d0,  0.d0,      ! 13 U_photon_T
     & 0.d0,  0.d0,      ! 14 U_photon_T  
     & 1.d0,  0.d0,      ! 15 U_Z_T  
     & 1.d0,  0.d0,      ! 16 C_Z_T  
     & 8*0.d0 /          ! 17:20 not used
      data an_FR/
*      Re_FR  Im_FR          MID channel
     & 0.d0,  0.d0,       ! 1   d W t SM 
     & 0.d0,  0.d0,       ! 2   s W t SM 
     & 0.d0,  0.d0,       ! 3   b W t SM 
     & 2*0.d0,            ! not used
     & 2*0.d0,            ! 5   b H+- 
     & 2*0.d0,            ! 6   b H+- T* 
     & 8*0.d0,            ! 7:10   not used
     & 0.d0,   0.d0,      ! 11 U_Gluon_T  
     & 0.d0,   0.d0,      ! 12 C_Gluon_T  
     & 0.d0,   0.d0,      ! 13 U_photon_T
     & 0.d0,   0.d0,      ! 14 U_photon_T  
     & 1.d0,   0.d0,      ! 15 U_Z_T  
     & 1.d0,   0.d0,      ! 16 C_Z_T  
     & 8*0.d0 /                         ! 17:20 not used
*****
      data an_HL/
*      Re_HL  Im_HL       MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 1.d0,  0.d0,     ! 11 U_Gluon_T  
     & 1.d0,  0.d0,     ! 12 C_Gluon_T  
     & 1.d0,  0.d0,     ! 13 U_photon_T
     & 1.d0,  0.d0,     ! 14 U_photon_T  
     & 1.d0,  0.d0,     ! 15 U_Z_T  
     & 1.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /                         ! 17:20 not used
      data an_HR/
*      Re_HR  Im_HR      MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 1.d0,   0.d0,    ! 11 U_Gluon_T  
     & 1.d0,   0.d0,    ! 12 C_Gluon_T  
     & 1.d0,   0.d0,    ! 13 U_photon_T
     & 1.d0,   0.d0,    ! 14 U_photon_T  
     & 1.d0,   0.d0,    ! 15 U_Z_T  
     & 1.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
******
      data an_XL/
*      Re_XL  Im_XL       MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,  0.d0,     ! 11 U_Gluon_T  
     & 0.d0,  0.d0,     ! 12 C_Gluon_T  
     & 0.d0,  0.d0,     ! 13 U_photon_T
     & 0.d0,  0.d0,     ! 14 U_photon_T  
     & 0.d0,  0.d0,     ! 15 U_Z_T  
     & 0.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used

      data an_XR/
*      Re_XR  Im_XR       MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,   0.d0,    ! 11 U_Gluon_T  
     & 0.d0,   0.d0,    ! 12 C_Gluon_T  
     & 0.d0,   0.d0,    ! 13 U_photon_T
     & 0.d0,   0.d0,    ! 14 U_photon_T  
     & 0.d0,   0.d0,    ! 15 U_Z_T  
     & 0.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
****
      data an_YL/
*      Re_YL  Im_YL        MID channel
     & 0.d0,  0.0d0,    ! 1   d W t SM 
     & 0.d0,  0.0d0,    ! 2   s W t SM 
     & 0.d0,  0.0d0,    ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,  0.d0,     ! 11 U_Gluon_T  
     & 0.d0,  0.d0,     ! 12 C_Gluon_T  
     & 0.d0,  0.d0,     ! 13 U_photon_T
     & 0.d0,  0.d0,     ! 14 U_photon_T  
     & 0.d0,  0.d0,     ! 15 U_Z_T  
     & 0.d0,  0.d0,     ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
      data an_YR/
*      Re_YR  Im_YR       MID channel
     & 0.d0,  0.d0,     ! 1   d W t SM 
     & 0.d0,  0.d0,     ! 2   s W t SM 
     & 0.d0,  0.d0,     ! 3   b W t SM 
     & 2*0.d0,          ! not used
     & 2*0.d0,          ! 5   b H+- 
     & 2*0.d0,          ! 6   b H+- T* 
     & 8*0.d0,          ! 7:10   not used
     & 0.d0,   0.d0,    ! 11 U_Gluon_T  
     & 0.d0,   0.d0,    ! 12 C_Gluon_T  
     & 0.d0,   0.d0,    ! 13 U_photon_T
     & 0.d0,   0.d0,    ! 14 U_photon_T  
     & 0.d0,   0.d0,    ! 15 U_Z_T  
     & 0.d0,   0.d0,    ! 16 C_Z_T  
     & 8*0.d0 /         ! 17:20 not used
**
       integer itwb
* 
       do jk = 1,20
         FR(jk) = (0.d0, 0.0d0)
         FL(jk) = (0.d0, 0.0d0)
         HR(jk) = (0.d0, 0.0d0)
         HL(jk) = (0.d0, 0.0d0)
         XR(jk) = (0.d0, 0.0d0)
         XL(jk) = (0.d0, 0.0d0)
         YR(jk) = (0.d0, 0.0d0)
         YL(jk) = (0.d0, 0.0d0)
       enddo
* read anomalous couplings 
      do I = 1,16
      if(I.le.3.and.mid(i,1).eq.-1) mid(I,1) = 0
       call TRANS_CPL(Irtyp(I),I, an_FL, an_FR, CR,CL)
        FR(I) = CR
        FL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_HL, an_HR, CR,CL)
        HR(I) = CR
        HL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_XL, an_XR, CR,CL)
        XR(I) = CR
        XL(I) = CL
       call TRANS_CPL(Irtyp(I),I, an_YL, an_YR, CR,CL)
        YR(I) = CR
        YL(I) = CL
*   set for FCNC: gluon + gamma FL = FR = 0
      if(I.ge.11.AND.mid(i,1).eq.-1) then 
       FL(i) = (0.d0, 0.d0)
       FR(i) = (0.d0, 0.d0)
       HL(i) = (0.d0, 0.d0)
       HR(i) = (0.d0, 0.d0)
       XL(i) = (0.d0, 0.d0)
       XR(i) = (0.d0, 0.d0)
       YL(i) = (0.d0, 0.d0)
       YR(i) = (0.d0, 0.d0)
      endif
       if(i.ge.11.and.I.le.14) then
        FR(I) = (0.d0, 0.d0)
        FL(I) = (0.d0, 0.d0)
       endif
      enddo
*
      do I = 11,16
       A = cx_md(HL(i)) + cx_md(HR(i)) 
     &   + cx_md(XL(i)) + cx_md(XR(i)) 
     &   + cx_md(YL(i)) + cx_md(YR(i)) 
      if(A.le.0.d0) mid(i,1) = -1
      enddo
**

      itwb = 0
      If( FL(1).eq.(1.d0,0.d0).and.FR(1).eq.(0.d0,0.d0).
     &AND.FL(2).eq.(1.d0,0.d0).and.FR(2).eq.(0.d0,0.d0).
     &AND.FL(3).eq.(1.d0,0.d0).and.FR(3).eq.(0.d0,0.d0)) then
       itwb = 0
      Else
       itwb = 1
      EndIf  
*
      write(*,*) 
     &'***********************************************'
      If(itwb.eq.0) then
        write(*,*) 
     &'* SM couplings for t W d/s/b verticex         *'
      else
       write(*,*) 
     &'* new parameterization of Anomalous couplings *'
      write(*,*) 
     &'* for t W d/s/b vertex                        *'
      endif
      write(*,*) 
     &'***********************************************'
      write(*,*)
     &'*  gamma^mu * (FL P_L + FR P_R) '
      do I = 1,3
       x0 = FL(I)*conjg(FL(i))+FR(i)*conjg(FR(i))
       write(*,*) ' ',I,' : ',nam(I),' sqrt(FL2+FR2)',dsqrt(X0),
     & ' FL',FL(i),'  FR',FR(i)
      enddo
      write(*,*) 
     &'*                                             *'

      if( mid(11,1).ge.0.OR.mid(12,1).ge.0.
     & OR.mid(13,1).ge.0.OR.mid(14,1).eq.0.
     & OR.mid(15,1).ge.0.OR.mid(16,1).ge.0) then     
      write(*,*) 
     &'* FCNC top quark anomalous couplings          *'
      write(*,*) 
     &'*                                             *'
      write(*,*)
     &'*  gamma^mu * (FL P_L + FR P_R) '

      do I = 15,16
       x0 = FL(I)*conjg(FL(i))+FR(i)*conjg(FR(i))
       if(mid(I,1).ge.0) write(*,*) 
     & ' ',I,' : ',nam(I),' sqrt(FL2+FR2) ',dsqrt(X0),
     & ' FL',FL(i),' FR',FR(i)
      enddo
      endif

      IF(itwb.eq.1.OR.mid(11,1).ge.0.OR.mid(12,1).ge.0.
     & OR.mid(13,1).ge.0.OR.mid(14,1).eq.0.
     & OR.mid(15,1).ge.0.OR.mid(16,1).ge.0) THEN 
      write(*,*) 
     &'*                                             *'
      write(*,*) 
     &'***********************************************'
       write(*,*) 
     &'* new parameterization of Anomalous couplings *'
      write(*,*) 
     &'***********************************************'
      If(itwb.eq.1) then
      do I = 1,3
       A = cx_md(HL(i)) + cx_md(HR(i)) 
      if(A.gt.0.d0) then
      write(*,*) '',I,': ',nam(I),' HL',HL(I),' HR',HR(I)
*      write(*,*) '    XL',XL(i),' XR',XR(i),'  YL',YL(i),' YR',YR(i)
      endif
      enddo
      EndIf
      do I = 11,16
       A = cx_md(HL(i)) + cx_md(HR(i)) 
     &   + cx_md(XL(i)) + cx_md(XR(i)) 
     &   + cx_md(YL(i)) + cx_md(YR(i)) 
      if(A.gt.0.d0) then
       write(*,*) '',I,': ',nam(I),' HL',HL(I),' HR',HR(I)
       write(*,*) '    XL',XL(i),' XR',XR(i),'  YL',YL(i),' YR',YR(i)
      endif
      enddo
      ENDIF

      do I = 1,16
        HL(i) = HL(i) / rpar(50)
        HR(i) = HR(i) / rpar(50)
       if((i.eq.11.or.i.eq.12).AND.irtyp(i).eq.4) then
        HR(i)=HR(i)*rpar(28)/Rpar(50)
        HL(i)=HL(i)*rpar(28)/Rpar(50)
        YR(i) = -YR(i)
        YL(i) = -YL(i)
        XR(i) = XR(i) - YR(i) 
        XL(i) = XL(i) - YL(i) 
       endif

       XL(i) = XL(i) / rpar(50)**2
       XR(i) = XR(i) / rpar(50)**2
       YL(i) = YL(i) / rpar(50)**2 
       YR(i) = YR(i) / rpar(50)**2
      enddo
*      return
*
* 2222 call RP_FCNC_READ  ! read parameters in Rui&Pedro format
      return
      end  
