
*----------------------------------------------------------------------------*
*.. author : Serge Slabospitsky   24.10.99                                   *
*....                                                                        *
      subroutine LIPS_RES_TWO(R, Par1, Par2, P1, P2, Ves)      
*     ---------------------------------------------------                    *
*                                                                            *
*  calculation of the LIPS with TWO resonances in the final state            *
*  with inclusion of denominators                                            *
*                                                                            *
*   R -> P1 (-> X1)  P2 (-> X2)                                              *
*                                                                            *
*                    R2(R -> P1 P2)                                          *
*  ---------------------------------------------------------                 *
*  [(P1**2 - m1**2)**2 + g1**2] [(P2**2 - m2**2)**2 + g2**2]                 *
*                                                                            *
*  LIPS(P1 -> X1) and LIPS(P2 -> X2)   are not included                      *
*                                                                            *
*... input :                                                                 *
*  R   is  5-momentum of initial system                                      *
*  Par1(1) is pole mass of the first resonance                               *
*  Par1(2) = width(R1) * Par1(1)                                             *
*  Par1(3) is the minimal invariant mass    of the first resonace            *
*  Par2(1:3) have the same meaning, but for the second resonance             *
*                                                                            *
*... output :                                                                *
*  P1 and P2 are 5-momenta of final resonances                               *
*  ves is the weight                                                         * 
*............................................................................*

      implicit none
      double precision R(5), Par1(3), Par2(3), P1(5), P2(5)
      double precision  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common  /piconst/ pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision ves
      double precision p2s, plim(2), wgt1, wgt2, ves12
*
      plim(1) = par1(3)
      plim(2) = r(5) - par1(3)
      call brtwig(plim, par1(1), par1(2), wgt1, p2s)
      P1(5) = p2s

      plim(1) = par2(3)
      plim(2) = r(5) - p1(5)
      call brtwig(plim, par2(1), par2(2), wgt2, p2s)
      p2(5) = p2s !  dsqrt(par2(1)**2 + par2(2) * tan(q0 + dq*PYR(0))) 
      call LIPS2 (R, P1, P2, Ves12)
       VES = pi2_3 * pi2_3 * ves12 * wgt1 * wgt2 
      return
      end
