*----------------------------------------------------------------------------*
*  matrix element for the W Q Qbar process                                   *
*.. author: Serge Slabospitsky                                               *
*.. 09.11.2003                                                               *
*                                                                            *
      subroutine MwQQ_new(k1,k2, q1, q2, L1, L2, ves)
*     ---------------------------------------------------                    *
*   q1  qbar2 --> W+ (-> e+(l1) nu(l2)) Q  Qbar                              *
*   k1   k2              PL     PN      q1 q2                                *
*   W-boson decay is included and W-boson is OFF-SHELL                       * 
*   denominators from gluon and W-boson propagators are removed and          *
*   calculated in LIPS (see RLIP43 routine)                                  *
*   amq is mass of q1 (or q2)                                                *
*............................................................................*
      Implicit none
      include "txpar.inc" 
      double precision amq, amq2
      double precision pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      common/piconst/  pi, pi2, pi4, pi2_3, pi2_4, pi2_6
      double precision k1(5), k2(5), q1(5), q2(5), L1(5), L2(5)
      double precision q(5), r(5), x1(5), x2(5)
      double precision SCALP, t1, t2, t3 
      double precision qq2, xx1, xx2, R2, rk1, rk2, rl1, rl2, k1k2,l1l2
      double precision qk1, qk2, ql1, ql2, k1l1, k1l2, k2l1, k2l2 
      double precision coef, ves 
      integer i

      LOGICAL first
      DATA first /.TRUE./
      SAVE first, Coef
*......
      if(first) THEN
      coef = 32.d0 * rpar(10)*((4.*pi)**2)*(rpar(26)/dsqrt(2.d0))**4 
      first=.FALSE.
      ENDIF
* running
      amq = q1(5)
      amq2 = amq**2
      do i=1,4
       q(i) = q1(i) + q2(i)
       r(i) = q1(i) - q2(i)
       x1(i) = q(i) - k2(i)
       x2(i) = k1(i) - q(i)
      enddo

      qq2 = SCALP(q, q)
      xx1 = SCALP(x1, x1)
      xx2 = SCALP(x2, x2)
      R2  = SCALP(r, r)
      rk1 = SCALP(r, k1)
      rk2 = SCALP(r, k2)
      rl1 = SCALP(r, L1)
      rl2 = SCALP(r, L2)
      qk1 = SCALP(q, k1)
      ql1 = SCALP(q, L1)
      qk2 = SCALP(q, k2)
      ql2 = SCALP(q, L2)
      k1k2 = SCALP(k1, k2)
      k1l1 = SCALP(k1, L1)
      k1l2 = SCALP(k1, L2)
      k2l1 = SCALP(k2, L1)
      k2l2 = SCALP(k2, L2)
      L1L2 = SCALP(L1, L2)

      t1 = xx1*rk2*rl2 
     &+ ql2*(qq2*qk2 + 2.d0*rk2**2 + 4.d0*amq2*qk2)
     &- 2.d0*k2l2*(qq2*amq2 + rk2**2 + qq2*qk2 - qk2**2)
      t1 = t1 * k1l1

      t2 = xx2*rk1*rl1 
     &+ ql1*(qq2*qk1 + 2.d0*rk1**2 + 4.d0*amq2*qk1)
     &- 2.d0*k1l1*(qq2*amq2 + rk1**2 + qq2*qk1 - qk1**2)
      t2 = t2 * k2l2

      t3 = -xx1*xx2*k1l1*k2l2
     & + qq2*qq2*(L1L2*K1K2 + K1L1*K2L2 - K1L2*K2L1)
     & + 4.d0*QQ2*K1K2*K1L1*K2L2
     & - 2.d0*QQ2*K1L1*(QL2*K1K2 + QK1*K2L2 - QK2*K1L2)
     & - 2.d0*QQ2*K2L2*(QL1*K1K2 + QK2*K1L1 - QK1*K2L1)
     & + QQ2*R2*(L1L2*K1K2 - K1L2*K2L1)
     & + RK1*RK2*(4.d0*K1L1*K2L2 - 2.d0*K1L1*QL2 - 2.d0*K2L2*QL1
     &          + 2.d0*QL1*QL2 - QQ2*L1L2)
     & + RK1*RL2*(2.d0*K1L1*QK2 - 2.d0*QL1*QK2 + QQ2*K2L1)
     & + RL1*RK2*(2.d0*K2L2*QK1 - 2.d0*QL2*QK1 + QQ2*K1L2)
     & + RL1*RL2*(2.d0*QK1*QK2 - QQ2*K1K2)
     & + R2*QK1*(QL2*K2L1 - QK2*L1L2)
     & + R2*QL1*(QK2*K1L2 - QL2*K1K2)

      t1 = t1 / XX1**2
      t2 = t2 / XX2**2
      t3 = t3 / (XX1*XX2) 

      ves =  ( (t1 + t2 + t3) / qq2) * coef * rpar(15)**2
      end
