*----------------------------------------------------------------------------*
************------------------------------------------------------************
*. . . . . . . MATRIX element calculation . . . . . . . . . . . . . . . . . .*
*----------------------------------------------------------------------------*
*  author : Serge Slabospitsky                                               *
*  01.03.2002                                                                *
*  matrix element for the H* process                                         *
*  U(q1)  D_bar(q2) --> W + H(q) -> t(p1) b~(p2)                             *
* Yukawa couplings with running q-masses                                     *
*  
*............................................................................*

      subroutine sng_01(q1, q2, p1, p2, ves)

      implicit none

      include "txpar.inc" 
      double precision  q1(5), q2(5)   ! momenta of initial light quarks
      double precision  p1(5), p2(5)   ! momenta of top, b 
      double precision  q(5)           ! =  q1 + q2 
      double precision Ves, vesH, vesW, vesI, coef, zW, zH, dW, dH

      double precision SCALP, s, sqs, LWW, LW(4), LH(4), LI(4)
      integer I
      double precision vt(3,4), epsi(4), HR 
      common /topol1/ HR(4) 
      double precision rs(5), rb(5), f(5) 
      double precision p1p2,p1q2,p1q,p1rs,p1f, p2q1,p2q,p2rs,p2f, 
     & rbrs,rbq,q1q2, rsq, qf
      double precision u1, u2, u3, u4,u5,u6 
      double precision mu1, mu2, m1, m2, dm12 
      integer iu,id, it, ib  ! flavors of initial (iu id) and final (it ib)
      common /isng01/iu,id,it,ib
      double precision HCPL,       HCPL2   
      common/HPMCPL/   HCPL(-20:20), HCPL2(-20:20)
      double precision ga1,gb1,ga2,gb2
*
      LOGICAL first
      SAVE first, coef
      DATA first /.TRUE./
*......... 
*..RPAR(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..RPAR(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(41)     : W-boson mass,       Rpar(42) = Rpar(41)**2                 *
*..Rpar(43)     : W-boson width,      Rpar(44) = M(W) * Width(W)             *
*..Rpar(51)     : charged Higgs mass, Rpar(52) = Rpar(51)**2                 *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(54)     : M(H+-) * Width(H+-)                                        *
*..Rpar(55)     : tan(beta),          Rpar(56) = (1/tan(beta))               *
*..ipar(21)      : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
*............................................................................*
      IF(first) THEN        ! initializing
       coef = rpar(10) * rpar(26)**4 / 4.d0      ! W-exchange
       if(ipar(21).lt.0) coef = coef/ 3.d0       ! tau nu production 
      first=.FALSE.
      ENDIF
* masses sqared
       mu1 = q1(5)**2    ! m1**2
       mu2 = q2(5)**2
       m1  = p1(5)**2
       m2  = p2(5)**2
       dm12 = m1 - m2 
      call Mass2(q1, q2, s, sqs) 
      q(5) = sqs
      zW = s - Rpar(42)
*      zW = s
      zH = s - Rpar(52)
      dW = zW*zW + Rpar(44)**2
*      dW = zW*zW 
    
      dH = zH*zH + Rpar(54)**2

      ga1 = hcpl(iu)
      gb1 = hcpl(id)
      ga2 = hcpl(it)
      gb2 = hcpl(ib)
       do i = 1,4
        q(I) = q1(i) + q2(i)
        rs(I) = mu1 * q2(i) + mu2 * q1(i) 
        rb(I) = m1  * p2(i) + m2  * q1(i) 
        f(I)  = q1(5)*ga1 * q2(i) - q2(5)*gb1 * q1(i) 
       enddo
*
      p1p2 = scalp(p1, p2) 
      p1q2 = scalp(p1, q2) 
      p1rs = scalp(p1, rs) 
      p1f  = scalp(p1, f) 
      p1q  = scalp(p1, q) 
      p2q1 = scalp(p2, q1) 
      p2rs = scalp(p2, rs) 
      p2q  = scalp(p2, q) 
      p2f  = scalp(p2, f) 
      rbrs = scalp(rb, rs) 
      rbq  = scalp(rb, q ) 
      q1q2 = scalp(q1,q2) 
      qf   = scalp(q, f) 
      rsq  = scalp(rs, q) 
* additional variables
*..Rpar(131) = m(D) * tan(beta)      Rpar(132) = m(U) * cot(beta)            *
*..Rpar(133) = m(S) * tan(beta)      Rpar(134) = m(C) * cot(beta)            *
*..Rpar(135) = m(B) * tan(beta)      Rpar(136) = m(T) * cot(beta)            *
*
      U1 = (ga1**2 + gb1**2) * q1q2 - 2.d0 * ga1 * gb1 * q1(5)*q2(5)
      U2 = (ga2**2 + gb2**2) * p1p2 - 2.d0 * ga2 * gb2 * p1(5)*p2(5)
      U3 =  ga2**2 - gb2**2 
      U4 =  p1(5)*ga2 + p2(5)*gb2 
      U5 = zW * ZH       + Rpar(44) * Rpar(54)
      U6 = zW * Rpar(54) - ZH * Rpar(44) 
*  W contribution
      vesw = 4.d0*p1q2*p2q1 - 2.d0*rbrs/Rpar(42)+Rbq/Rpar(42)**2
      vesW = vesW * coef / dW 
* Higgs exchange
      vesH = coef * U1 * U2 / dH
* interference
      vesI = p1(5)*ga2*p2f - p2(5)*gb2*p2f 
     & - (qf/Rpar(42))*(p1(5)*p2(5)*(p2(5)*ga2 - p1(5)*gb2) 
     &                   +   p1p2  *(p1(5)*ga2 - p2(5)*gb2)) 
      vesI = vesI * (-2.d0 * coef * U5) / dw / dH
* total weight
      if    (abs(ipar(21)).eq.1)  then
       ves = vesW                    ! W exchange, t bbar
      elseif(abs(ipar(21)).eq.2) then
       ves = vesH                    ! H exchange, t bbar
      elseif(abs(ipar(21)).eq.3) then
       ves = vesW + vesH + vesI      ! W +  H + Interf 
      endif
*... polarisation

      call EPSPR(f, p2, p1, epsi)

      if(ipar(21).gt.0) then     
*                      t b~ production   : top polarisation
      call Vortas(p1, vt)

       do i = 1,4
        LWW = -4.d0 * p1(5)* p2q1 * q2(I)
     &      -  2.d0 * p1(5)* (p2q*rs(I) - p1rs*p2(I)) / Rpar(42)  
     &      +  rsq * p1(5)* dm12 * p2(I)    / Rpar(42)**2
        LW(I) = coef * LWW        / dW          ! W contribution
        LH(I) = coef * p1(5) * U1 * U3*p2(I) / dH       ! H contribution

        LWW = p1(5)*p2(5)*gb2*f(I) + ga2*(p1f*p2(I) - p1p2*f(I))
     &      - (qf/Rpar(42)) * p1(5)* U4 * p2(I)
        LWW = U5 * LWW  + U6 * ga2 * epsi(I)
        LI(I) = -2.d0* coef * LWW / dw / dH            ! interference
       enddo
      elseif(ipar(21).lt.0) then     
*                      tau nu production   : tau polarisation
      call vortas(p2, vt)

       do i = 1,4
        LWW = 4.d0 * p2(5) * p1q2 * q1(I)
     &      - 2.d0 * p2(5) * (p1q*rs(I) - p2rs*p1(I)) / Rpar(42)  
     &      +  rsq * p2(5) * dm12 * p1(I)     / Rpar(42)**2
        LW(I) = coef * LWW          / dW                ! W contribution
        LH(I) = coef * p2(5) * U1*U3*p1(I) / dH         ! H contribution

        LWW = p1(5)*p2(5)*ga2*f(I) + gb2*(p2f*p1(I) - p1p2*f(I))
     &      - (qf/Rpar(42)) * p2(5)*U4 * p1(I)
        LWW = U5 * LWW  +  U6 * gb2 * epsi(I)
        LI(I) = -2.d0 * coef * LWW / dw / dH            ! interference
       enddo
      endif

      do i = 1,3
      if    (abs(ipar(21)).eq.1) then
       lww = LW(4)*vt(i,4) - LW(1)*vt(i,1)   ! W exchange
     &     - LW(2)*vt(i,2) - LW(3)*vt(i,3) 
      elseif(abs(ipar(21)).eq.2) then
       lww = LH(4)*vt(i,4) - LH(1)*vt(i,1)   ! H exchange
     &     - LH(2)*vt(i,2) - LH(3)*vt(i,3) 
      elseif(abs(ipar(21)).eq.3) then         ! W +  H + Interf 
       lww = (LW(4)+LH(4)+LI(4))*vt(i,4) 
     &     - (LW(1)+LH(1)+LI(1))*vt(i,1) 
     &     - (LW(2)+LH(1)+LI(2))*vt(i,2) 
     &     - (LW(3)+LH(1)+LI(3))*vt(i,3) 
      endif
       HR(I) = LWW / Ves
*       HR(I) = - LWW / Ves
      enddo
       HR(4) = 0.d0
      if(ipar(33).eq.2) ves = ves * (1.d0-hr(3))/2.d0
      if(ipar(33).eq.3) ves = ves * (1.d0+hr(3))/2.d0

      return
      end
