c----------------------------------------------------------------------------c
*********************  top quark decay routines  *****************************
c----------------------------------------------------------------------------c
*.. author : Serge Slabospitsky   17.10.2002                                 *
*... anomalous top decay : FCNC :  t -> q gamma (gluon)                      * 
      subroutine Top_dec_01(id, kf, MT) 
*     -------------------------------------------                            *
*                                                                            *
*  all momenta in top rest frame                                             *
*  |M|**2 is constant                                                        *
*                                                                            *
*     t -> gamma (gluon) + quark                                             *
*     R    q               k                                                 *
*... input :                                                                 *
*  Id = 11(12) : t -> U(C) + gluon                                           *
*  Id = 13(14) : t -> U(C) + photon                                          *
*  KF = 6 (-6)  is top flavor,  MT is initial top mass                       *
*... output :                                                                *
*  K and Q are 5-momenta of final quark and photon (gluon) in top rest frame *
*............................................................................*

      implicit none
      include "txpar.inc" 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
*...........
      integer mxdc
      parameter (mxdc=20)   
      integer ndec, kdec
      double precision pdm, pdpl, pol(5)
      common /decmom/ pdm(mxdc,5), pdpl(mxdc,4), ndec, kdec(mxdc,3)
      double precision MT, R(5), k(5), q(5), Ves
      double precision H0(4), X0(4), B0(4), AH(4), AX(4), BB(4) 
      integer idc, I, J, KF, ID, j8,j9
      LOGICAL first
      SAVE first 
      DATA first /.TRUE./
      double complex   FL,     FR,      HL,    HR,
     &                 XL,     XR,      YL,    YR
      common /ANOMCPL/FL(20), FR(20), HL(20), HR(20), 
     &                XL(20), XR(20), YL(20), YR(20) 
*.................................. 

      idc = id - 10
      ndec = 2     ! number of final particles
         
      do j8 = 1,mxdc
       do j9 = 1,3
          pdm(j8,j9) = 0.d0
         pdpl(j8,j9) = 0.d0
         kdec(j8,j9) = 0
       enddo
          pdm(j8,4) = 0.d0
          pdm(j8,5) = 0.d0
         pdpl(j8,4) = 0.d0
      enddo

      IF(first) then 
      if(ipar(33).ge.2) then
       print*,'********************************************'
       print*,'*  IPAR(33) value = ',ipar(33) 
       print*,'*  is implemented for t -> q gamma(gluon)  *'
       print*,'********************************************'
      endif 
        
       do j9 = 1,4
         H0(j9) = 0.d0
         X0(j9) = 0.d0
         B0(j9) = 0.d0
         AH(j9) = 0.d0
         AX(j9) = 0.d0
         BB(j9) = 0.d0
       enddo

       do J = 11, 14
        I = J - 10
        H0(I) = HR(j)*conjg(HR(j)) + HL(j)*conjg(HL(j))
         AH(I) = HL(j)*conjg(HR(j)) - HR(j)*conjg(HL(j))
        X0(I) = XR(j)*conjg(XR(j)) + XL(j)*conjg(XL(j))
         AX(I) = XL(j)*conjg(XR(j)) - XR(j)*conjg(XL(j))
        B0(I) = HR(j)*conjg(XR(j)) + XR(j)*conjg(HR(j))
     &        + HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
         BB(I) = HL(j)*conjg(XL(j)) + XL(j)*conjg(HL(j))
     &         - HR(j)*conjg(XR(j)) - XR(j)*conjg(HR(j))
       enddo

      first = .false. 

      ENDIF

       kdec(2,1) = FID(1,id,1) * kf / abs(kf)   ! for t -> q A quark
       kdec(1,1) = FID(1,id,2)                  ! KF code of gluon or photon 
       k(5)  = mq(ABS(kdec(2,1)))               ! quark
       Q(5)  = 0.d0                             ! gluon(photon)


      R(4) = MT 
      R(5) = R(4)

      call LIPS2 (R,  k, q, VES)
      ves = 16.d0*H0(idc) + x0(idc)*mt**2 - 4.d0*MT*b0(idc)


       pol(4) = 0.d0
       pol(5) = 0.d0
      do I = 1,3
       pol(I) = 
     & 32.d0*AH(idc) + 2.d0*AX(idc)*mt**2 - 8.d0*MT*BB(idc)
       pol(I) = pol(i)*q(i)/MT/ves
       pol(I) = -pol(i) ! transit to 3-dimensional space 
      enddo

      do I = 1,5
       pdm(2,I) = k(i)
       pdm(1,I) = q(i)
       pdm(20,I) = pol(i)
       if(kf.eq.-6) pdm(20,I) = -pdm(20,I) 
      enddo
      return
      end
