******************************************************************************
*                                                                            *
*          T o p R e X : 4.23                                                *
*          Date:  10.12.2006                                                 *
*----------------------------------------------------------------------------*
*                                                                            *
*... author : Serge Slabospitsky                                             *
*                                                                            *
      subroutine TopReX(FRAME,BEAM,TARGET, Ecm)
*     -----------------------------------------------                        *
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
*  setting user's parameters and  initializations of user's routines         *
*  for PYTHIA >= 6.226                                                       *
*............................................................................*
*                                                                            *
*............................................................................*
* Txsel = -1 : PYTHIA process                                                *
* Txsel = 1 : txpro(1) + txpro(2), doubling counting is removed              *
* Txsel = 2 : txpro(30+31+32+33),  doubling counting is removed              *
* Txpro( 1) :  EW top : W g(2->2)                                            *
* Txpro( 2) :  EW top : W g(2->3)                                            *
* Txpro( 3) :  EW top : t W                                                  *
* Txpro( 4) :  EW top : W* -> t bbar                                         *
* Txpro( 5) :  W Q Qbar                                                      *
* Txpro( 6) :  W+-  -> tau nu                                                *
* Txpro( 7) :  W+- (-> tau nu) JET                                           *
* Txpro( 8) :  H+-  -> t bbar                                                *
* Txpro( 9) :  H+-  -> tau nu                                                *
* Txpro(10) :  H+- (-> tau nu) JET                                           *
* Txpro(20) :  gg+qq~ -> tt~,  'on-shell ',  S. Slabospitsky                 *
* Txpro(23) :  Z Q Qbar                                                      *
* Txpro(24) : g g -> Z Z    with   Z -> f fbar                               *
* Txpro(25) : q q~ -> t tbar gamma                                           *
* Txpro(30) :  FCNC top : g u -> top                                         *
* Txpro(31) :  FCNC top : q q~ -> top u(c)                                   *
* Txpro(32) :  FCNC top : g g  -> top u(c)                                   *
* Txpro(33) :  FCNC top : g q  -> top g                                      *
* Txpro(61) :  q q~   -> H+ H-                                               *
*                                                                            *
* Txpro(99) :  testing and development                                       *
*............................................................................*
*..... GLOBAL     TopReX    parameters                                       *
*. . . . . .  INTEGER parameters . . . . . . . . . . . . . . . . . .. . . .  *
*..Ipar(1)      ! current TopReX process's code                              *
*  Ipar(2)      : current event                                              *
*..Ipar(3)      : evolution scale type for PDF                               *
*..Ipar(4)      : evolution scale type for alpha_S                           *
*  Ipar(5)      : 0(1) quark masses are taken from PYTHIA(PDG)               *
*  Ipar(6)      : 0(1) s,c,b,t mass value are QCD-evaluated(fixed)           *
*               : Ipar(6) is used only for evaluation of H+- couplings       *
*..Ipar(7)      : KF code of Q-quark for WQQbar                              *
*..Ipar(8)      : INIT flag                                                  *
*..Ipar(9)     : continuation flag                                           *
*..Ipar(10)     : 1(0) (no)print  sigma for each q, qbar contribution        *
*..Ipar(11)     : 0/1 to NOT/print output from single top production         *
*..Ipar(12)     : 0/1 print information about hard process                   *
*. . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . *
*..Ipar(16)     : flag for first/second order in alpha-s evaluation (PYTHIA) *
*..Ipar(17)     : check max. diff. X-section, during run                     *
*..Ipar(18)     : 1/0 evaluate PDF uncertainty                               *
*..Ipar(19)     : = MSTP(52) from PYTHIA                                     *
*..Ipar(21)     : W-exchange: > 0 tb, <0 tau nu, 1 W, 2 H, 3 (W+H+Int)       *
*..Ipar(22)     : 0: gg + qqbar, 1: gg,   2: qqbar                           *
*..Ipar(23)     : Zqq, 0: gam* + Z,   1: gam*, 2: Z                          *
*..Ipar(24)     : gg->ZZ, 0: SM box, 1: box + Higgs, 2: Higgs                *
*..Ipar(25)     : free
*..Ipar(26)     : bW 0 SM + FCNC, 1 - SM, 2 - FCNC                           *
*  Ipar(31)     : 1(0) running (fixed) top-mass according top width          *
*..Ipar(32)     : 1/0 finite/zero width of the W-boson in decay chain        *
*  ipar(33)     : 1(0) take (not) into account spin of produced top quarks   *
*..Ipar(41)     : number of the particles in the hard process                *
*..Ipar(42)     : sig*10**(Ipar(42))                                         *
*  ipar(50)     : number of current color                                    *
*..Ipar(51)     : num. of events used for estimation of SigMax               *
*..ipar(52)     : num. of events used for estimation of M**2                 *
*..Ipar(53)     : num. of MC entries  for estimates  of H+- and T decays     *
*..Ipar(100)    : current process number = Ipar(1)                           *
*..Ipar(101)    : current process position in /HEPRUP/ list, i.e. 1,2,3..NPRUP
*..Ipar(120)    : final leptons for ADD:                                     *
*. . . . . . . . . . . . . .  . . . . . . . . . . . . . . . . . . . . . . .  *
*. . . . . .  DOUBLE PRECISION parameters . . . . . . . . . . . . . . . . .  *
*..Rpar(1)      : Ecm                                                        *
*..Rpar(2)      : S = Ecm**2                                                 *
*..Rpar(3)      : Evolution scale for PDF                                    *
*..Rpar(4)      : Evolution scale for alpha_s                                *
*..Rpar(5)      : parameter for Q-scale evaluation for PDF                   *
*..Rpar(6)      : parameter for Q-scale evaluation for alpha_s               *
*..Rpar(7)      : x1 the momentum fraction x taken by the parton from a beam *
*..Rpar(8)      : x2 the momentum fraction x taken by the parton from a target
*
*.............. couplings ...................................................*
*..Rpar(10)     : 0.38939d0     transformation 1/GeV**2 to mb                *
*..Rpar(11)     : alpha_QED = (1/128) is electromagnetic coupling            *
*..Rpar(12)     : 4.*pi*rpar(11)  = (electric charge)**2                     *
*..Rpar(13)     : sqrt(4.*pi*rpar(11)) is electric charge                    *
*..Rpar(14)     : G_Fermi                                                    *
*..Rpar(15)     : alpha_QCD = QCD coupling used for event                    *
*..Rpar(16)     : 4*pi * Rpar(15) = (QCD charge)**2 = (g_s)**2               *
*..Rpar(17)     : sqrt(4*pi * Rpar(15)) = QCD charge                         *
*..Rpar(18)     : 10**(9 - ipar(42))
*.......
*..Rpar(21)     : sin(theta_W)                                               *
*..Rpar(22)     : cos(theta_W)                                               *
*..Rpar(23)     : sin(theta_W)**2                                            *
*..Rpar(24)     : cos(theta_W)**2                                            *
*..Rpar(25)     : sin(2*theta_W) = 2 * sin(theta_W) * cos(theta_W)           *
*..Rpar(26)     : g = g_weak  = e / sin(theta_W)                             *
*..Rpar(27)     : g_z         = e / sin(2*theta_W)                           *
*..Rpar(28)     : v vacuum expectation value * 246/sqrtr(2) GeV              *
*
*.............. top quark parameters ........................................*
*..Rpar(30)     : width of t-> d  W decay at tree level (SM case)            *
*..Rpar(31)     : width of t-> s  W decay at tree level (SM case)            *
*..Rpar(32)     : width of t-> b  W decay at tree level (SM case)            *
*..Rpar(33)     : width of t-> b4 W decay at tree level (SM case)            *
*..Rpar(34)     : total t-quark decay width                                  *
*..Rpar(35)     : width of t -> b H+- decay channel                          *
*..Rpar(36)     : M(top) * width(total top)                                  *
*..Rpar(37)     : current value of M(top) generated with B.W.                *
*.............. W-boson and Z-boson parameters  .............................*
*..Rpar(41)     : W-boson mass                                               *
*..Rpar(42)     : Rpar(41)**2                                                *
*..Rpar(43)     : W-boson width                                              *
*..Rpar(44)     : M(W) * Width(W)                                            *
*...                                                                         *
*..Rpar(45)     : Z-boson mass                                               *
*..Rpar(46)     : Rpar(45)**2                                                *
*..Rpar(47)     : Z-boson width                                              *
*..Rpar(48)     : M(Z) * Width(Z)                                            *
*............................................................................*
*..Rpar(50)     : New Physics scale (1 TeV), FCNC                            *
*.............. charged Higgs parameters  ...................................*
*..Rpar(51)     : charged Higgs mass                                         *
*..Rpar(52)     : Rpar(51)**2                                                *
*..Rpar(53)     : total charged Higgs decay width                            *
*..Rpar(54)     : M(H+-) * Width(H+-)                                        *
*..Rpar(55)     : tan(beta)                                                  *
*..Rpar(56)     : (1/tan(beta))                                              *
*............................................................................*
*..Rpar(57)     : neutral Higgs (SM) mass                                    *
*..Rpar(58)     : total Higgs decay width                                    *
*..Rpar(59)     : M(H) * Width(H)                                            *
*............................................................................*
*..Rpar(61:63) are for processes Ipar(1) = 50, 51, 52 only                   *
*..Rpar(61)    : gVV, relative coupling of Higgs boson(H0) to W and Z bosons *
*..Rpar(62)    : a, scalar Yukawa coupling of Higgs boson(H0) to top quarks  *
*..Rpar(63)    : a~, pseudoscalar Yukawa coupling of H0 boson to top quarks  *
*............................................................................* 
*..Rpar(64)    : total X-section for the process, evaluated for each event   *
*..Rpar(65)    : differential cross section (in PB) for current event        *
*..Rpar(67)    : 2.d0,  PTmin(Z), IPAR(1) = 34, ZZ-production                *
*..Rpar(68)    : 20.d0, PTmin(q)    ==> Rpar(81), IPAR(1) = 11, T-channel    *
*..Rpar(69)    : 10.d0, PTmin(Bbar) ==> Rpar(82), IPAR(1) = 11, T-channel    *
*..Rpar(70)    : MW/Z_min  for virtual W/Z in heavy particle decay           *
*..... kinematic ............................................................*
*..Rpar(71)    : Shat       for hard process                                 *
*..Rpar(72)    : That       for hard process                                 *
*..Rpar(73)    : Uhat       for hard process                                 *
*..Rpar(74)    : sqrt(Shat) for hard process                                 *
*..Rpar(75)    : PThat      for hard process                                 *
*..Rpar(76)    : PThat**2   for hard process                                 *
*..Rpar(77)    : M(QQbar)_MIN  for W/Z Q Qbar production                     *
*..Rpar(78)    : M(QQbar)_MAX  for W/Z Q Qbar production                     *
*..Rpar(79)    : M(ffbar)_MIN  for gamma* or Z*                              *
*..Rpar(80)    : M(ffbar)_MAX  for gamma* or Z*                              *
*..Rpar(81)    : kinematic cut,  >=3 final state, PTmin(q) for Ipar(11)      *
*..Rpar(82)    : kinematic cut,  >=3 final state, PTmin(Bbar) for Ipar(11)   *
*..Rpar(83:99) : kinematic cuts, >=3 final state                             *
*............................................................................* 
*..Rpar(101)   : CKIN(1) = sqrt(Shat_MIN) for hard process                   *
*..Rpar(102)   : CKIN(2) = sqrt(Shat_MAX) for hard process                   *
*..Rpar(103)   : CKIN(3) = PThat_MIN                                         *
*..Rpar(104)   : CKIN(4) = PThat_MAX                                         *
*............................................................................*
*...........  Graviton* production,  ADD scenario                            *
*..Rpar(121)     : M_exdim,                         ADD scenario             *
*..Rpar(122)     : n_exdim,  Graviton* production,  ADD scenario             *
*..Rpar(123)     : mKK mass of KK-excitation,       ADD scenario             *
*..Rpar(124)     : recommended PThat_MIN            ADD scenario             *
*..Rpar(125)     : factor_ADD                                                *
*............................................................................*
*...........  Black Hole (BH) production                                     *
*  Rpar(131)     : Planck scale, GeV                                         *
*  Rpar(132)     : n extra dimensions                                        *
*  Rpar(133)     : BR(BH -> q qbar X)                                        *
*  Rpar(134)     : BR(BH -> g g    X) / 2                                    *
*  Rpar(135)     : BR(BH -> l l'   X)                                        *
*  Rpar(136)     : BR(BH -> gamma,W,Z X) + BR(BH -> Higgs  X)                *
*  Rpar(137)     : BR(BH -> Higgs  X)                                        *
*............................................................................*

      implicit none
*
* PYTHIA common
      include "txpar.inc" 
      include "pydat_62.inc"
      integer MINT
      double precision VINT
      COMMON/PYINT1/MINT(400),VINT(400)
      integer         MSEL,MSELPD,MSUB,     KFIN
      double precision                                     CKIN
      COMMON /PYSUBS/ MSEL,MSELPD,MSUB(500),KFIN(2,-40:40),CKIN(200)
*
      CHARACTER*(*) FRAME,BEAM,TARGET
      character*12 XFRAME, XBEAM, XTARGET
      common /TXFBT/XFRAME, XBEAM, XTARGET
      CHARACTER CHFRAM*12,CHBEAM*12,CHTARG*12
      INTEGER MAXPUP
      PARAMETER (MAXPUP=100)
      INTEGER IDBMUP,PDFGUP,PDFSUP,IDWTUP,NPRUP,LPRUP
      double precision EBMUP,XSECUP,XERRUP,XMAXUP
      COMMON/HEPRUP/IDBMUP(2),EBMUP(2),PDFGUP(2),PDFSUP(2),
     &IDWTUP,NPRUP,XSECUP(MAXPUP),XERRUP(MAXPUP),XMAXUP(MAXPUP),
     &LPRUP(MAXPUP)
      SAVE /HEPRUP/
*
      double precision Ecm 
      double precision mq, mq2
      common/massql/ mq(0:20), mq2(0:20)
      integer IBEAM, ITARGET
*............................................................................*
      CHFRAM=FRAME//' '
      CHBEAM=BEAM//' '
      CHTARG=TARGET//' '
*
      call TX_TIT                    ! print TopReX title
*
      Rpar(1) = Ecm               ! ECM energy
      Rpar(2) = Rpar(1) * Rpar(1) ! S = Ecm**2 
*
      XFRAME  = FRAME 
      XBEAM   = BEAM
      XTARGET = TARGET
*
      call tx_mult
      call Rep_PDF               ! print information about PDF set
*
      MSEL = 0   ! return full user control to TopReX
*
      Ipar(19) = mstp(52)
*      

      call IBMTG(chBEAM,chTARG,  IBEAM, ITARGET)
       IDBMUP(1) = IBEAM 
       IDBMUP(2) = ITARGET 
       EBMUP(1)  = rpar(1) / 2.d0
       EBMUP(2)  = rpar(1) / 2.d0
       IDWTUP    = 1

       if(Ipar(16).eq.2)  then
        if(MSTP(51).eq.7) mstp(2) = 1  ! first  order in alpha_s 
        if(MSTP(51).eq.8) mstp(2) = 2  ! second order in alpha_s 
       endif

       MSTU(12)= 0  ! switch off print PYTHIA logo 
       MSTP(122)=0  ! switch off X section print out     
      call PYINIT(chFRAM,chBEAM,chTARG, Ecm)
       MSTP(122)=1  ! switch on X section print out
* 
* start to evaluation of Toprex parameters
*........integer parameters

      call TXWEAK                 ! set TopReX additional parameters
      call TX_DEC_TABLE           ! set decay table for top, W+-, H+-, Z 
*  set kinematics
        rpar(101) = CKIN(1)         ! sqrt(Shat) MIN
        rpar(102) = CKIN(2)         ! sqrt(Shat) MAX
        Rpar(103) = CKIN(3)         ! PThat      MIN
*..................................................................
      call UPEVNT   ! first call - initialization and evaluation of Sigmax
      return
      end
