*----------------------------------------------------------------------------*
* polarization vectors                                                       *
*----------------------------------------------------------------------------*
*.. author:  Serge Slabospitsky  30.05.2006                                  *
* Massive Vector Boson Polarization vectors                                  *
* k is v-boson 4-momentum,  MV is mass, since very often k(5) = sqrt(k^2)    *
* output: ev(mu) - polarization vector                                       *
* WARNING: sum on forth vectors has                                          *
*  sign PLUS  for (k2 - m2)/k2 > 0 ==> return IP =  4                        *
*  sign MINUS for (k2 - m2)/k2 < 0 ==> return IP = -4                        *
*----------------------------------------------------------------------------*

      subroutine VpolBos(IP, mv, k, ev) 
*     -------------------------                                 
      implicit none
      double precision mv, k(5), ev(5), kt, kv, k2 
      integer IP, I ! number of polarization vector
      double precision deps ! minimal value 
      data deps /0.0000001d0/ ! e-7
*
      do i = 1,5
        ev(i) = 0.d0
      enddo
      kt = dsqrt(k(1)**2 + k(2)**2) 
      kv = dsqrt(k(1)**2 + k(2)**2 + k(3)**2) 
*
      If(    IP.eq.1) then
       if(kt.le.deps) then
          ev(1) = 1.d0  
       else
          ev(1) =  k(2) / kt    ! e1_x
          ev(2) = -k(1) / kt    ! e1_y
       endif
      ElseIf(IP.eq.2) then
       if(kt.le.deps) then
          ev(2) = 1.d0     
       else
          ev(1) =  k(3)*k(1) / kt / kv ! e2_x
          ev(2) =  k(3)*k(2) / kt / kv ! e2_y
          ev(3) =  -    kt   / kv      ! e2_z
       endif
      ElseIf(IP.eq.3) then
       if(kt.le.deps) then
          ev(4) = k(3) / mv   ! e3_0
          ev(3) = k(4) / mv   ! e3_z
       else
          ev(1) =  k(4)*k(1) / kv / mv ! e3_x
          ev(2) =  k(4)*k(2) / kv / mv ! e3_y
          ev(3) =  k(4)*k(3) / kv / mv ! e3_z
          ev(4) =       kv        / mv ! e3_0
       endif
      ElseIf(IP.eq.4) then  ! OFF-shell case
        k2 = k(4)**2 - kv**2
       if(dabs(k2).le.deps) return 
       kt = dsqrt(2.d0*dabs( (k2 - mv**2)/k2) ) / mv
          ev(1) =  kt * k(1)  ! e4_x
          ev(2) =  kt * k(2)  ! e4_y
          ev(3) =  kt * k(3)  ! e4_z
          ev(4) =  kt * k(4)  ! e4_0
        if( ((k2 - mv**2)/k2).le.0.d0) IP = - IP
      EndIf
      return
      end
